@@ -27,12 +27,19 @@ class KRunProxy : public QObject
 
     public:
 
-    explicit KRunProxy (QObject* parent = 0);
+    explicit KRunProxy (QObject* parent = nullptr);
 
     /**
      * opens the url from the existing file
      */
-    Q_INVOKABLE bool openUrl(const QString &filePath);
+    Q_INVOKABLE bool openUrl(const QString &fileUrl);
+
+    /**
+     * Runs the service (application)
+     * @param serviceName the name of the desktop file without extension
+     * @return true on success
+     */
+    Q_INVOKABLE bool openService(const QString &serviceName);
 };
 
 #endif
